@@ -28,6 +28,7 @@ from oslo_messaging import conffixture as messaging_fixture
 from oslotest import base
 from testtools import testcase
 
+from designate.common import constants
 import designate.conf
 from designate import exceptions
 from designate import objects
@@ -81,10 +82,10 @@ class TestCase(base.BaseTestCase):
     }]
 
     quota_fixtures = [{
-        'resource': 'zones',
+        'resource': constants.QUOTA_ZONES,
         'hard_limit': 5,
     }, {
-        'resource': 'records',
+        'resource': constants.QUOTA_ZONE_RECORDS,
         'hard_limit': 50,
     }]
 
@@ -211,7 +212,11 @@ class TestCase(base.BaseTestCase):
 
     ptr_fixtures = [
         {'ptrdname': 'srv1.example.com.'},
-        {'ptrdname': 'srv1.example.net.'}
+        {'ptrdname': 'srv1.example.net.'},
+        {'ptrdname': 'srv2.example.com.'},
+        {'ptrdname': 'srv3.example.com.'},
+        {'ptrdname': 'srv4.example.com.'},
+        {'ptrdname': 'srv5.example.com.'},
     ]
 
     blacklist_fixtures = [{
@@ -387,6 +392,8 @@ class TestCase(base.BaseTestCase):
         self.central_service = self.start_service('central')
 
         self.admin_context = self.get_admin_context()
+        self.admin_context_all_tenants = self.get_admin_context(
+            all_tenants=True)
         storage_driver = CONF['service:central'].storage_driver
         self.storage = storage.get_storage(storage_driver)
 
@@ -436,10 +443,11 @@ class TestCase(base.BaseTestCase):
     def get_context(self, **kwargs):
         return DesignateContext(**kwargs)
 
-    def get_admin_context(self):
+    def get_admin_context(self, **kwargs):
         return DesignateContext.get_admin_context(
             project_id=utils.generate_uuid(),
-            user_id=utils.generate_uuid())
+            user_id=utils.generate_uuid(),
+            **kwargs)
 
     # Fixture methods
     def get_quota_fixture(self, fixture=0, values=None):
@@ -782,34 +790,36 @@ class TestCase(base.BaseTestCase):
         return self.storage.create_zone_export(
             context, objects.ZoneExport.from_dict(zone_export))
 
-    def wait_for_import(self, zone_import_id, errorok=False):
+    def wait_for_import(self, zone_import_id, error_is_ok=False, max_wait=10):
         """
            Zone imports spawn a thread to parse the zone file and
            insert the data. This waits for this process before continuing
         """
-        attempts = 0
-        while attempts < 20:
-            # Give the import a half second to complete
-            time.sleep(.5)
-
+        start_time = time.time()
+        while True:
             # Retrieve it, and ensure it's the same
             zone_import = self.central_service.get_zone_import(
-                self.admin_context, zone_import_id)
+                self.admin_context_all_tenants, zone_import_id
+            )
 
             # If the import is done, we're done
             if zone_import.status == 'COMPLETE':
                 break
 
             # If errors are allowed, just make sure that something completed
-            if errorok:
-                if zone_import.status != 'PENDING':
-                    break
+            if error_is_ok and zone_import.status != 'PENDING':
+                break
 
-            attempts += 1
+            if (time.time() - start_time) > max_wait:
+                break
 
-        if not errorok:
+            time.sleep(0.5)
+
+        if not error_is_ok:
             self.assertEqual('COMPLETE', zone_import.status)
 
+        return zone_import
+
     def _ensure_interface(self, interface, implementation):
         for name in interface.__abstractmethods__:
             in_arginfo = inspect.getfullargspec(getattr(interface, name))
